---
name: Error-Fix Database
description: IML error and fixes database. Provides `error_corpus.json`, a collection of common IML errors and their fixes. Search it using jq or grep to find relevant errors and their fixes.
---

This directory contains `error_corpus.json`, a collection of common IML errors and their fixes. You can search it using `jq`, `grep`, etc. to find relevant errors and their fixes.

Its schema is defined in `error_corpus_schema.json`.
